@@ -1,21 +1,30 @@
 # -*- coding: utf-8 -*-
 """
-    flask_cors
-    ~~~~~~~~~~
+    test
+    ~~~~
+    Flask-CORS is a simple extension to Flask allowing you to support cross
+    origin resource sharing (CORS) using a simple decorator.
 
-    Flask-CORS extension module
+    :copyright: (c) 2014 by Cory Dolphin.
+    :license: MIT, see LICENSE for more details.
 """
-from _version import __version__
-import collections
 
+
+from _version import __version__
+
+import collections
 from datetime import timedelta
 from functools import update_wrapper
 
 from flask import make_response, request, current_app
 from six import string_types
 
-AccessControlAllowOrigin = 'Access-Control-Allow-Origin'
-
+# Common string constants
+ACL_ORIGIN = 'Access-Control-Allow-Origin'
+ACL_METHODS = 'Access-Control-Allow-Methods'
+ACL_HEADERS = 'Access-Control-Allow-Headers'
+ACL_CREDENTIALS = 'Access-Control-Allow-Credentials'
+ACL_MAX_AGE = 'Access-Control-Max-Age'
 
 def cross_origin(origins=None, methods=None, headers=None,
                  supports_credentials=False, max_age=None, send_wildcard=True,
@@ -76,8 +85,6 @@ def cross_origin(origins=None, methods=None, headers=None,
             and isinstance(headers, collections.Iterable)):
         headers = ', '.join(x for x in headers)
 
-    wildcard = origins == '*'
-
     if isinstance(max_age, timedelta):
         max_age = max_age.total_seconds()
 
@@ -86,6 +93,7 @@ def cross_origin(origins=None, methods=None, headers=None,
             # Determine origins when in the context of a request
             origins = _origins or current_app.config.get('CORS_ORIGINS', '*')
             origins_str = str(origins)
+            wildcard = origins_str == '*'
 
             if(not isinstance(origins, string_types)
                     and isinstance(origins, collections.Iterable)):
@@ -116,23 +124,23 @@ def cross_origin(origins=None, methods=None, headers=None,
                 # If the `origins` param is '*', either send the request's
                 # origin, or `*`
                 if send_wildcard:
-                    resp.headers[AccessControlAllowOrigin] = origins
+                    resp.headers[ACL_ORIGIN] = origins
                 else:
                     req_origin = request.headers.get('Origin', '*')
-                    resp.headers[AccessControlAllowOrigin] = req_origin
+                    resp.headers[ACL_ORIGIN] = req_origin
 
             # If not 'wildcard', send the string-joined-form of the
             # origins header
             else:
-                resp.headers[AccessControlAllowOrigin] = origins_str
+                resp.headers[ACL_ORIGIN] = origins_str
 
-            resp.headers['Access-Control-Allow-Methods'] = methods
+            resp.headers[ACL_METHODS] = methods
             if max_age:
-                resp.headers['Access-Control-Max-Age'] = str(max_age)
+                resp.headers[ACL_MAX_AGE] = str(max_age)
             if headers is not None:
-                resp.headers['Access-Control-Allow-Headers'] = headers
+                resp.headers[ACL_HEADERS] = headers
             if supports_credentials:
-                resp.headers['Access-Control-Allow-Credentials'] = 'true'
+                resp.headers[ACL_CREDENTIALS] = 'true'
             return resp
 
         # If True, intercept OPTIONS requests by modifying the view function
